TextFormFields class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TextFormFields
Constructors
-
TextFormFields({Key? key, String? hintText, TextAlign textAlign = TextAlign.start, bool enabled = true, bool readOnly = false, TextEditingController? textEditingController, EdgeInsetsGeometry contentPadding = const EdgeInsets.all(16), bool autoFocus = false, int maxLines = 1, int minLines = 1, bool obscureText = false, TextInputAction textInputAction = TextInputAction.next, String label = '', TextStyle? labelStyle, TextStyle? fieldStyle, TextStyle? hintStyle, TextStyle? errorStyle, Color borderColor = Colors.grey, Color focusColor = Colors.green, Color cursorColor = Colors.green, Color focusBorderColor = Colors.green, FocusNode? focusNode, TextInputType textInputType = TextInputType.text, InputDecoration? decoration, bool dense = true, Widget? icon, Widget? image, Widget? suffixIcon, Widget? prefixIcon, dynamic onChanged(String s)?, String? validator(String? s)?, dynamic onSaved(String? s)?, dynamic onFieldSubmitted(String s)?, List<
TextInputFormatter> ? inputFormatter, dynamic onEditingComplete()?, dynamic onTap()?, String obscuringCharacter = '•', bool filled = true, Color fillColor = Colors.white, bool isBorder = true, bool isPrefix = false, String? prefixText, String suffixText = '', BoxConstraints? suffixIconConstraints, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(10.0)), InputBorderType? borderType = InputBorderType.outline, TextStyle? prefixStyle, TextStyle? suffixStyle, String? errorText}) -
const
Properties
- autoFocus → bool
-
final
- borderColor → Color
-
final
- borderRadius → BorderRadius
-
final
- borderType → InputBorderType?
-
final
- contentPadding → EdgeInsetsGeometry
-
final
- cursorColor → Color
-
final
- decoration → InputDecoration?
-
final
- dense → bool
-
final
- enabled → bool
-
final
- errorStyle → TextStyle?
-
final
- errorText → String?
-
final
- fieldStyle → TextStyle?
-
final
- fillColor → Color
-
final
- filled → bool
-
final
- focusBorderColor → Color
-
final
- focusColor → Color
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintStyle → TextStyle?
-
final
- hintText → String?
-
final
- icon → Widget?
-
final
- image → Widget?
-
final
-
inputFormatter
→ List<
TextInputFormatter> ? -
final
- isBorder → bool
-
final
- isPrefix → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
final
- labelStyle → TextStyle?
-
final
- maxLines → int
-
final
- minLines → int
-
final
- obscureText → bool
-
final
- obscuringCharacter → String
-
final
- onChanged → dynamic Function(String s)?
-
final
- onEditingComplete → dynamic Function()?
-
final
- onFieldSubmitted → dynamic Function(String s)?
-
final
- onSaved → dynamic Function(String? s)?
-
final
- onTap → dynamic Function()?
-
final
- prefixIcon → Widget?
-
final
- prefixStyle → TextStyle?
-
final
- prefixText → String?
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffixIcon → Widget?
-
final
- suffixIconConstraints → BoxConstraints?
-
final
- suffixStyle → TextStyle?
-
final
- suffixText → String
-
final
- textAlign → TextAlign
-
final
- textEditingController → TextEditingController?
-
final
- textInputAction → TextInputAction
-
final
- textInputType → TextInputType
-
final
- validator → String? Function(String? s)?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited